@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# :copyright: (c) 2020 by Pavlo Dmytrenko.
+# :copyright: (c) 2021 by Pavlo Dmytrenko.
 # :license: MIT, see LICENSE for more details.
 
 """
@@ -13,6 +13,7 @@ A lightweight terminal spinner.
 from __future__ import absolute_import
 
 import contextlib
+import datetime
 import functools
 import itertools
 import signal
@@ -21,13 +22,13 @@ import threading
 import time
 
 from .base_spinner import default_spinner
-from .compat import PY2, basestring, builtin_str, bytes, iteritems, str
+from .compat import PY2, basestring, builtin_str, bytes, iteritems, str  # pylint: disable=redefined-builtin
 from .constants import COLOR_ATTRS, COLOR_MAP, ENCODING, SPINNER_ATTRS
 from .helpers import to_unicode
 from .termcolor import colored
 
 
-class Yaspin(object):
+class Yaspin(object):  # pylint: disable=useless-object-inheritance,too-many-instance-attributes
     """Implements a context manager that spawns a thread
     to write spinner frames into a tty (stdout) during
     context execution.
@@ -47,7 +48,7 @@ class Yaspin(object):
     # Thats why in Py2, output should be encoded manually with desired
     # encoding in order to support pipes and redirects.
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         spinner=None,
         text="",
@@ -57,6 +58,7 @@ class Yaspin(object):
         reversal=False,
         side="left",
         sigmap=None,
+        timer=False,
     ):
         # Spinner
         self._spinner = self._set_spinner(spinner)
@@ -74,6 +76,9 @@ class Yaspin(object):
         self._text = self._set_text(text)
         self._side = self._set_side(side)
         self._reversal = reversal
+        self._timer = timer
+        self._start_time = None
+        self._stop_time = None
 
         # Helper flags
         self._stop_spin = None
@@ -125,7 +130,7 @@ class Yaspin(object):
     def __getattr__(self, name):
         # CLI spinners
         if name in SPINNER_ATTRS:
-            from .spinners import Spinners
+            from .spinners import Spinners  # pylint: disable=import-outside-toplevel
 
             sp = getattr(Spinners, name)
             self.spinner = sp
@@ -218,6 +223,16 @@ class Yaspin(object):
         self._frames = self._set_frames(self._spinner, self._reversal)
         self._cycle = self._set_cycle(self._frames)
 
+    @property
+    def elapsed_time(self):
+        if self._start_time is None:
+            return 0
+
+        if self._stop_time is None:
+            return time.time() - self._start_time
+
+        return self._stop_time - self._start_time
+
     #
     # Public
     #
@@ -228,12 +243,16 @@ class Yaspin(object):
         if sys.stdout.isatty():
             self._hide_cursor()
 
+        self._start_time = time.time()
+        self._stop_time = None  # Reset value to properly calculate subsequent spinner starts (if any)  # pylint: disable=line-too-long
         self._stop_spin = threading.Event()
         self._hide_spin = threading.Event()
         self._spin_thread = threading.Thread(target=self._spin)
         self._spin_thread.start()
 
     def stop(self):
+        self._stop_time = time.time()
+
         if self._dfl_sigmap:
             # Reset registered signal handlers to default ones
             self._reset_signal_handlers()
@@ -300,9 +319,12 @@ class Yaspin(object):
             sys.stdout.write("\r")
             self._clear_line()
 
-            _text = to_unicode(text)
-            if PY2:
-                _text = _text.encode(ENCODING)
+            if isinstance(text, (builtin_str, str, bytes)):
+                _text = to_unicode(text)
+                if PY2:
+                    _text = _text.encode(ENCODING)
+            else:
+                _text = builtin_str(text)
 
             # Ensure output is bytes for Py2 and Unicode for Py3
             assert isinstance(_text, builtin_str)
@@ -379,6 +401,12 @@ class Yaspin(object):
         if self._side == "right":
             frame, text = text, frame
 
+        if self._timer:
+            sec, fsec = divmod(self.elapsed_time, 1)
+            text += " ({}.{:02.0f})".format(
+                datetime.timedelta(seconds=sec), 100 * fsec
+            )
+
         # Mode
         if not mode:
             out = "\r{0} {1}".format(frame, text)
