@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+#
+# :copyright: (c) 2021 by Pavlo Dmytrenko.
+# :license: MIT, see LICENSE for more details.
 
 """
 yaspin.spinners
@@ -10,13 +13,16 @@ A collection of cli spinners.
 import pkgutil
 from collections import namedtuple
 
+
 try:
     import simplejson as json
 except ImportError:
     import json
 
 
-SPINNERS_DATA = pkgutil.get_data(__name__, "data/spinners.json").decode("utf-8")
+SPINNERS_DATA = pkgutil.get_data(__name__, "data/spinners.json").decode(
+    "utf-8"
+)
 
 
 def _hook(dct):
